# NetMāgus Python Package
[![Updates](https://pyup.io/repos/github/rbcollins123/netmagus_python/shield.svg?token=fffb8c76-e275-451f-8ce0-1ec463f6d650)](https://pyup.io/repos/github/rbcollins123/netmagus_python/)
[![Python 3](https://pyup.io/repos/github/rbcollins123/netmagus_python/python-3-shield.svg?token=fffb8c76-e275-451f-8ce0-1ec463f6d650)](https://pyup.io/repos/github/rbcollins123/netmagus_python/)
[![Build Status](https://travis-ci.com/rbcollins123/netmagus_python.svg?token=dqosS7xWadx9zSztAYMC&branch=master)](https://travis-ci.com/rbcollins123/netmagus_python)

This Python package is to be used with the [NetMāgus](http://www.intelligentvisibility.com/netmagus) product from [Intelligent Visbility, Inc](http://www.intelligentvisibility.com).

It is used to create and exchange UI forms and Formula steps with the NetMāgus application.

The code has been tested and should work for both Python 2.7 and 3.5.

To install, simply use ```pip install netmagus```

Refer to the [NetMāgus](http://www.intelligentvisibility.com/netmagus) documentation for usage details.
